
/**
 ** Generated data (by mkcproc.pl)
 **/
#line 1 "bsecsynth.proc"

#include        <bse/bseplugin.h>
#include        <bse/bseprocedure.h>
#include        <bse/bsecsynth.h>
#include        <bse/bsemain.h>


#line 27 "bsecsynth.proc"



/* --- Export to BSE --- */
BseExportNode* bse__builtin_init_bsecsynth_gen_proc_c (void);
BseExportNode* bse__builtin_init_bsecsynth_gen_proc_c (void)
{
  return NULL;
}

/**
 ** Generated data ends here
 **/
